@@ -28,20 +28,20 @@
 #include "k3bglobals.h"
 #include "k3bfilesplitter.h"
 #include "k3bisooptions.h"
+#include "k3b_i18n.h"
 
-#include <kdebug.h>
-#include <kstandarddirs.h>
-#include <klocale.h>
-#include <ktemporaryfile.h>
-#include <kio/netaccess.h>
-#include <kio/global.h>
-#include <kio/job.h>
-#include <kstringhandler.h>
+#include <KIOCore/KIO/CopyJob>
+#include <KIOCore/KIO/Global>
+#include <KIOCore/KIO/Job>
+#include <KCoreAddons/KStringHandler>
 
-#include <qfile.h>
-#include <qregexp.h>
-#include <qdir.h>
-#include <qapplication.h>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QRegExp>
+#include <QtCore/QStandardPaths>
+#include <QtCore/QTemporaryFile>
+#include <QtWidgets/QApplication>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -95,7 +95,7 @@ K3b::IsoImager::IsoImager( K3b::DataDoc* doc, K3b::JobHandler* hdl, QObject* par
 
 K3b::IsoImager::~IsoImager()
 {
-    kDebug();
+    qDebug();
     cleanup();
     delete d;
 }
@@ -130,7 +130,7 @@ void K3b::IsoImager::handleMkisofsInfoMessage( const QString& line, int type )
 
 void K3b::IsoImager::slotProcessExited( int exitCode, QProcess::ExitStatus exitStatus )
 {
-    kDebug();
+    qDebug();
 
     cleanup();
 
@@ -187,7 +187,7 @@ void K3b::IsoImager::slotProcessExited( int exitCode, QProcess::ExitStatus exitS
 
 void K3b::IsoImager::cleanup()
 {
-    kDebug();
+    qDebug();
 
     // remove all temp files
     delete m_pathSpecFile;
@@ -257,7 +257,7 @@ void K3b::IsoImager::startSizeCalculation()
     m_process = new K3b::Process( this );
     m_process->setSplitStdout(true);
 
-    emit debuggingOutput( QLatin1String( "Used versions" ), QLatin1String( "mkisofs: " ) + d->mkisofsBin->version );
+    emit debuggingOutput( QLatin1String( "Used versions" ), QString::fromLatin1( "mkisofs: %1").arg(d->mkisofsBin->version()) );
 
     *m_process << d->mkisofsBin;
 
@@ -272,9 +272,9 @@ void K3b::IsoImager::startSizeCalculation()
     // ??? Seems it is not needed after all. At least mkisofs 1.14 and above don't need it. ???
     //  *m_process << dummyDir();
 
-    kDebug() << "***** mkisofs calculate size parameters:";
+    qDebug() << "***** mkisofs calculate size parameters:";
     QString s = m_process->joinedArgs();
-    kDebug() << s << endl << flush;
+    qDebug() << s << endl << flush;
     emit debuggingOutput("mkisofs calculate size command:", s);
 
     // since output changed during mkisofs version changes we grab both
@@ -288,16 +288,16 @@ void K3b::IsoImager::startSizeCalculation()
     // everything is written to stderr
     // last line is: "Total extents scheduled to be written = XXXXX"
 
-    connect( m_process, SIGNAL(stdoutLine(const QString&)),
-             this, SLOT(slotCollectMkisofsPrintSizeStdout(const QString&)) );
-    connect( m_process, SIGNAL(stderrLine(const QString&)),
-             this, SLOT(slotCollectMkisofsPrintSizeStderr(const QString&)) );
-    connect( m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+    connect( m_process, SIGNAL(stdoutLine(QString)),
+             this, SLOT(slotCollectMkisofsPrintSizeStdout(QString)) );
+    connect( m_process, SIGNAL(stderrLine(QString)),
+             this, SLOT(slotCollectMkisofsPrintSizeStderr(QString)) );
+    connect( m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
              this, SLOT(slotMkisofsPrintSizeFinished()) );
 
     // we also want error messages
-    connect( m_process, SIGNAL(stderrLine( const QString& )),
-             this, SLOT(slotReceivedStderr( const QString& )) );
+    connect( m_process, SIGNAL(stderrLine(QString)),
+             this, SLOT(slotReceivedStderr(QString)) );
 
     m_collectedMkisofsPrintSizeStdout = QString();
     m_collectedMkisofsPrintSizeStderr = QString();
@@ -341,7 +341,7 @@ void K3b::IsoImager::slotMkisofsPrintSizeFinished()
     // if m_collectedMkisofsPrintSizeStdout is not empty we have a recent version of
     // mkisofs and parsing is very easy (s.o.)
     if( !m_collectedMkisofsPrintSizeStdout.isEmpty() ) {
-        kDebug() << "(K3b::IsoImager) iso size: " << m_collectedMkisofsPrintSizeStdout;
+        qDebug() << "(K3b::IsoImager) iso size: " << m_collectedMkisofsPrintSizeStdout;
         m_mkisofsPrintSizeResult = m_collectedMkisofsPrintSizeStdout.toInt( &success );
     }
     else {
@@ -368,7 +368,7 @@ void K3b::IsoImager::slotMkisofsPrintSizeFinished()
     }
     else {
         m_mkisofsPrintSizeResult = 0;
-        kDebug() << "(K3b::IsoImager) Parsing mkisofs -print-size failed: " << m_collectedMkisofsPrintSizeStdout;
+        qDebug() << "(K3b::IsoImager) Parsing mkisofs -print-size failed: " << m_collectedMkisofsPrintSizeStdout;
         emit infoMessage( i18n("Could not determine size of resulting image file."), MessageError );
         jobFinished( false );
     }
@@ -432,20 +432,20 @@ void K3b::IsoImager::start()
         return;
     }
 
-    connect( m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
-             this, SLOT(slotProcessExited(int, QProcess::ExitStatus)) );
-    connect( m_process, SIGNAL(stderrLine( const QString& )),
-             this, SLOT(slotReceivedStderr( const QString& )) );
+    connect( m_process, SIGNAL(finished(int,QProcess::ExitStatus)),
+             this, SLOT(slotProcessExited(int,QProcess::ExitStatus)) );
+    connect( m_process, SIGNAL(stderrLine(QString)),
+             this, SLOT(slotReceivedStderr(QString)) );
 
-    kDebug() << "***** mkisofs parameters:\n";
+    qDebug() << "***** mkisofs parameters:\n";
     QString s = m_process->joinedArgs();
-    kDebug() << s << endl << flush;
+    qDebug() << s << endl << flush;
     emit debuggingOutput("mkisofs command:", s);
 
     if( !m_process->start( KProcess::SeparateChannels ) ) {
         // something went wrong when starting the program
         // it "should" be the executable
-        kDebug() << "(K3b::IsoImager) could not start mkisofs";
+        qDebug() << "(K3b::IsoImager) could not start mkisofs";
         emit infoMessage( i18n("Could not start %1.", QLatin1String("mkisofs")), K3b::Job::MessageError );
         jobFinished( false );
         cleanup();
@@ -455,11 +455,11 @@ void K3b::IsoImager::start()
 
 void K3b::IsoImager::cancel()
 {
-    kDebug();
+    qDebug();
     m_canceled = true;
 
     if( m_process && m_process->isRunning() ) {
-        kDebug() << "terminating process";
+        qDebug() << "terminating process";
         m_process->terminate();
     }
     else if( active() ) {
@@ -564,7 +564,7 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
     int volsetSize = m_doc->isoOptions().volumeSetSize();
     int volsetSeqNo = m_doc->isoOptions().volumeSetNumber();
     if( volsetSeqNo > volsetSize ) {
-        kDebug() << "(K3b::IsoImager) invalid volume set sequence number: " << volsetSeqNo
+        qDebug() << "(K3b::IsoImager) invalid volume set sequence number: " << volsetSeqNo
                  << " with volume set size: " << volsetSize << endl;
         volsetSeqNo = volsetSize;
     }
@@ -622,14 +622,11 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
         }
     }
 
-    if( filesGreaterThan2Gb ) {
-        emit infoMessage( i18n("Found files bigger than 2 GB. These files will only be fully accessible if mounted with UDF."),
-                          MessageWarning );
-
-        // in genisoimage 1.1.3 "they" silently introduced this aweful parameter
-        if ( d->mkisofsBin->hasFeature( "genisoimage" ) && d->mkisofsBin->version >= K3b::Version( 1, 1, 3 ) ) {
-            *m_process << "-allow-limited-size";
-        }
+    // in genisoimage 1.1.3 "they" silently introduced this aweful parameter
+    if (filesGreaterThan2Gb && d->mkisofsBin->hasFeature("genisoimage") && d->mkisofsBin->version() >= K3b::Version(1, 1, 3)) {
+        *m_process << "-allow-limited-size";
+        emit infoMessage(i18n("Found files bigger than 2 GB. These files will be fully accessible."),
+                MessageInfo);
     }
 
     bool udf = m_doc->isoOptions().createUdf();
@@ -733,9 +730,9 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
 int K3b::IsoImager::writePathSpec()
 {
     delete m_pathSpecFile;
-    m_pathSpecFile = new KTemporaryFile();
+    m_pathSpecFile = new QTemporaryFile();
     if ( m_pathSpecFile->open() ) {
-        kDebug() << "Opened path spec file" << m_pathSpecFile->fileName();
+        qDebug() << "Opened path spec file" << m_pathSpecFile->fileName();
         QTextStream s( m_pathSpecFile );
 
         // recursive path spec writing
@@ -750,7 +747,7 @@ int K3b::IsoImager::writePathSpec()
 int K3b::IsoImager::writePathSpecForDir( K3b::DirItem* dirItem, QTextStream& stream )
 {
     if( !m_noDeepDirectoryRelocation && dirItem->depth() > 7 ) {
-        kDebug() << "(K3b::IsoImager) found directory depth > 7. Enabling no deep directory relocation.";
+        qDebug() << "(K3b::IsoImager) found directory depth > 7. Enabling no deep directory relocation.";
         m_noDeepDirectoryRelocation = true;
     }
 
@@ -827,14 +824,21 @@ void K3b::IsoImager::writePathSpecForFile( K3b::FileItem* item, QTextStream& str
     if( m_doc->bootImages().contains( dynamic_cast<K3b::BootItem*>(item) ) ) { // boot-image-backup-hack
 
         // create temp file
-        KTemporaryFile temp;
+        QTemporaryFile temp;
         temp.setAutoRemove( false );
         temp.open();
         QString tempPath = temp.fileName();
         temp.remove();
 
-        if( !KIO::NetAccess::file_copy( KUrl(item->localPath()), tempPath ) ) {
-            emit infoMessage( i18n("Failed to backup boot image file %1",item->localPath()), MessageError );
+        KIO::CopyJob* copyJob = KIO::copyAs(QUrl::fromLocalFile(item->localPath()), QUrl::fromLocalFile(tempPath), KIO::HideProgressInfo);
+        bool copyJobSucceed = true;
+        connect(copyJob, &KJob::result, [&](KJob*) {
+            if( copyJob->error() != KJob::NoError ) {
+                emit infoMessage( i18n("Failed to backup boot image file %1",item->localPath()), MessageError );
+                copyJobSucceed = false;
+            }
+        } );
+        if( !copyJob->exec() || !copyJobSucceed ) {
             return;
         }
 
@@ -853,7 +857,7 @@ void K3b::IsoImager::writePathSpecForFile( K3b::FileItem* item, QTextStream& str
 bool K3b::IsoImager::writeRRHideFile()
 {
     delete m_rrHideFile;
-    m_rrHideFile = new KTemporaryFile();
+    m_rrHideFile = new QTemporaryFile();
     m_rrHideFile->open();
 
     QTextStream s( m_rrHideFile );
@@ -874,7 +878,7 @@ bool K3b::IsoImager::writeRRHideFile()
 bool K3b::IsoImager::writeJolietHideFile()
 {
     delete m_jolietHideFile;
-    m_jolietHideFile = new KTemporaryFile();
+    m_jolietHideFile = new QTemporaryFile();
     m_jolietHideFile->open();
 
     QTextStream s( m_jolietHideFile );
@@ -895,7 +899,7 @@ bool K3b::IsoImager::writeJolietHideFile()
 bool K3b::IsoImager::writeSortWeightFile()
 {
     delete m_sortWeightFile;
-    m_sortWeightFile = new KTemporaryFile();
+    m_sortWeightFile = new QTemporaryFile();
     m_sortWeightFile->open();
 
     QTextStream s( m_sortWeightFile );
@@ -1028,14 +1032,16 @@ QString K3b::IsoImager::dummyDir( K3b::DirItem* dir )
     // permissions we create different dummy dirs to be passed to mkisofs
     //
 
-    QDir _appDir( KStandardDirs::locateLocal( "appdata", "temp/" ) );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::DataLocation ) + "/temp/";
+    QDir().mkpath(path);
+    QDir _appDir( path );
 
     //
     // create a unique isoimager session id
     // This might become important in case we will allow multiple instances of the isoimager
     // to run at the same time.
     //
-    QString jobId = qApp->sessionId() + "_" + QString::number( m_sessionNumber );
+    QString jobId = qApp->sessionId() + '_' + QString::number( m_sessionNumber );
 
     if( !_appDir.cd( jobId ) ) {
         _appDir.mkdir( jobId );
@@ -1050,13 +1056,13 @@ QString K3b::IsoImager::dummyDir( K3b::DirItem* dir )
     if( !dir->localPath().isEmpty() ) {
         // permissions
         if( k3b_stat( QFile::encodeName(dir->localPath()), &statBuf ) == 0 ) {
-            name += "_";
+            name += '_';
             name += QString::number( statBuf.st_uid );
-            name += "_";
+            name += '_';
             name += QString::number( statBuf.st_gid );
-            name += "_";
+            name += '_';
             name += QString::number( statBuf.st_mode );
-            name += "_";
+            name += '_';
             name += QString::number( statBuf.st_mtime );
 
             perm = true;
@@ -1066,7 +1072,7 @@ QString K3b::IsoImager::dummyDir( K3b::DirItem* dir )
 
     if( !_appDir.cd( name ) ) {
 
-        kDebug() << "(K3b::IsoImager) creating dummy dir: " << _appDir.absolutePath() << "/" << name;
+        qDebug() << "(K3b::IsoImager) creating dummy dir: " << _appDir.absolutePath() << "/" << name;
 
         _appDir.mkdir( name );
         _appDir.cd( name );
@@ -1080,14 +1086,16 @@ QString K3b::IsoImager::dummyDir( K3b::DirItem* dir )
         }
     }
 
-    return _appDir.absolutePath() + "/";
+    return _appDir.absolutePath() + '/';
 }
 
 
 void K3b::IsoImager::clearDummyDirs()
 {
-    QString jobId = qApp->sessionId() + "_" + QString::number( m_sessionNumber );
-    QDir appDir( KStandardDirs::locateLocal( "appdata", "temp/" ) );
+    QString jobId = qApp->sessionId() + '_' + QString::number( m_sessionNumber );
+    QString path = QStandardPaths::writableLocation( QStandardPaths::DataLocation ) + "/temp/";
+    QDir().mkpath(path);
+    QDir appDir( path );
     if( appDir.cd( jobId ) ) {
         QStringList dummyDirEntries = appDir.entryList( QStringList() << "dummydir*", QDir::Dirs );
         for( QStringList::iterator it = dummyDirEntries.begin(); it != dummyDirEntries.end(); ++it )
@@ -1109,4 +1117,4 @@ QIODevice* K3b::IsoImager::ioDevice() const
     return m_process;
 }
 
-#include "k3bisoimager.moc"
+
